@@ -5,3 +5,7 @@ get_oml_code = function(str) {
   }
   as.integer(stri_extract_first_regex(str, "\\d+"))
 }
+
+get_oml_message = function(str) {
+  stri_trim_both(stri_replace_first_regex(str, ".*<oml:message>(.*)</oml:message>.*", "$1"))
+}
